.. _ref-highlevel:

.. currentmodule:: pyedflib.highlevel

EDF/BDF ``highlevel`` functions
-------------------------------

.. autofunction:: change_polarity
.. autofunction:: rename_channels
.. autofunction:: anonymize_edf
.. autofunction:: drop_channels
.. autofunction:: compare_edf
.. autofunction:: read_edf_header
.. autofunction:: write_edf_quick
.. autofunction:: write_edf
.. autofunction:: read_edf
.. autofunction:: make_signal_headers
.. autofunction:: make_signal_header
.. autofunction:: make_header
.. autofunction:: phys2dig
.. autofunction:: dig2phys

